@@ -1,9 +1,12 @@
 import sys
+
 sys.path.append("...")
 from lucd.driver import Driver
 
+
 def test_create_driver():
     driver = Driver()
-    chrome = driver.create_driver(headless=True)
+    driver.headless = True
+    chrome = driver.create()
     assert chrome.title == "Blog posts"
     chrome.quit()
