@@ -4,6 +4,7 @@ import platform
 from pathlib import Path
 import subprocess
 
+
 DRIVER = Path(__file__).resolve().absolute().parent / "driver"
 
 
@@ -14,11 +15,7 @@ class Util:
         config_file = os.path.join(DRIVER, "config.json")
         if not os.path.isfile(config_file):
             with open(config_file, "w") as config:
-                data = {
-                    "system":platform.system(),
-                    "version":"",
-                    "chromedriver":""
-                }
+                data = {"system": platform.system(), "version": "", "chromedriver": ""}
                 config.write(json.dumps(data))
         return config_file
 
@@ -26,7 +23,7 @@ class Util:
         config_file = self.create_chrome_driver_config()
         config_data = json.load(open(config_file, "r"))
         if version:
-            config_data["version"]=version
+            config_data["version"] = version
         if chromedriver:
             config_data["chromedriver"] = chromedriver
         with open(config_file, "w") as config:
@@ -37,7 +34,12 @@ class Util:
         Get the path of the chrome driver
         """
         try:
-            chrome_path = subprocess.check_output(['whereis', 'google-chrome']).decode('utf-8').strip().split()[1]
-        except:
+            chrome_path = (
+                subprocess.check_output(["whereis", "google-chrome"])
+                .decode("utf-8")
+                .strip()
+                .split()[1]
+            )
+        except IndexError:
             return False
-        return chrome_path
\ No newline at end of file
+        return chrome_path
